@@ -1,45 +1,26 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "bondsetting.h"
 #include "bondsetting_p.h"
 
-#if !NM_CHECK_VERSION(1, 0, 0)
-#include <nm-setting-bond.h>
-#endif
-
-//define the deprecated&dropped values
-#if NM_CHECK_VERSION(1, 0, 0)
 #define NM_SETTING_BOND_INTERFACE_NAME "interface-name"
-#endif
 
-#include <QtCore/QDebug>
+#include <QDebug>
 
 NetworkManager::BondSettingPrivate::BondSettingPrivate()
     : name(NM_SETTING_BOND_SETTING_NAME)
-{ }
+{
+}
 
 NetworkManager::BondSetting::BondSetting()
     : Setting(Setting::Bond)
     , d_ptr(new BondSettingPrivate())
-{ }
+{
+}
 
 NetworkManager::BondSetting::BondSetting(const Ptr &other)
     : Setting(other)
@@ -120,7 +101,7 @@ QVariantMap NetworkManager::BondSetting::toMap() const
     return setting;
 }
 
-QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::BondSetting &setting)
+QDebug NetworkManager::operator<<(QDebug dbg, const NetworkManager::BondSetting &setting)
 {
     dbg.nospace() << "type: " << setting.typeAsString(setting.type()) << '\n';
     dbg.nospace() << "initialized: " << !setting.isNull() << '\n';
